@@ -5,6 +5,8 @@ from colorama import Fore
 
 
 def clean_spacing(text):
+    text = re.sub("\\{\\{", "{{ ", text)
+    text = re.sub("\\}\\}", " }}", text)
     text = re.sub("\\{\\{\\s+", "{{ ", text)
     text = re.sub("\\s+\\}\\}", " }}", text)
     return text
