@@ -20,8 +20,15 @@ def get_function_arg_names(func):
     return list(signature(func).parameters.keys())
 
 
-def partialize_engine_func(func, engine):
-    if "engine" in get_function_arg_names(func):
-        return partial(func, engine=engine)
+def partialize_function(func, partial_kwargs=None, **kwargs):
+    partial_kwargs = partial_kwargs or ["engine"]
+    function_args = get_function_arg_names(func)
+
+    kwargs_to_partialize = {
+        k: v for k, v in kwargs.items() if k in function_args and k in partial_kwargs
+    }
+
+    if kwargs_to_partialize:
+        return partial(func, **kwargs_to_partialize)
     else:
         return func
